@@ -131,7 +131,7 @@ public class SysInstallMojo extends AbstractMojo {
     @Parameter(property = "maven.ignoreRules", defaultValue = "maven.ignoreRules", required = true)
     private String mavenIgnoreRules;
 
-    @Parameter(property = "maven.publishedRules", defaultValue = "maven.ignoreRules", required = true)
+    @Parameter(property = "maven.publishedRules", defaultValue = "maven.publishedRules", required = true)
     private String mavenPublishedRules;
 
     /**
@@ -767,6 +767,8 @@ public class SysInstallMojo extends AbstractMojo {
     protected void relocatePoms() throws IOException {
         if (relocatedArtifacts != null) {
             for (Dependency relocated : relocatedArtifacts) {
+                relocated.setType(new File(fullJarName()).exists() ? "jar" : "pom");
+
                 getLog().info("Relocating " + relocated.formatCompactNotation());
 
                 File relocatedPath = new File(packagePath() + "/usr/share/maven-repo" + artifactPath(relocated.getGroupId(), relocated.getArtifactId(), relocated.getVersion()));
@@ -784,6 +786,7 @@ public class SysInstallMojo extends AbstractMojo {
                 "  <groupId>" + relocateArtifact.getGroupId() + "</groupId>\n" +
                 "  <artifactId>" + relocateArtifact.getArtifactId() + "</artifactId>\n" +
                 "  <version>" + relocateArtifact.getVersion() + "</version>\n" +
+                "  <packaging>" + relocateArtifact.getType() + "</packaging>\n" +
                 "  <properties>\n" +
                 "    <debian.package>" + destPackage + "</debian.package>\n" +
                 "  </properties>\n" +
