@@ -414,7 +414,7 @@ public class DependenciesSolver {
 
             if (exploreProjects && !pom.getModules().isEmpty()) {
                 if (interactive && !askedToFilterModules) {
-                    filterModules = !new YesNoQuestion("This project contains modules. Include all modules?", true).ask();
+                    filterModules = !new YesNoQuestion("This project contains modules. Include all modules? (no to select them individually)", true).ask();
                     askedToFilterModules = true;
                 }
                 for (String module : pom.getModules()) {
@@ -879,6 +879,7 @@ public class DependenciesSolver {
             System.out.println("    POM file with the versions found in the repository");
             System.out.println("  --base-directory: path to root directory of package");
             System.out.println("  --non-explore: doesn't explore directories for pom.xml");
+            System.out.println("  --build: build mode (don't write the .poms and rules files)");
             return;
         }
 
@@ -893,6 +894,7 @@ public class DependenciesSolver {
         boolean generateJavadoc = false;
         boolean interactive = true;
         boolean offline = false;
+        boolean build = false;
 
         // Parse parameters
         int i = inc(-1, args);
@@ -926,7 +928,10 @@ public class DependenciesSolver {
                 baseDirectory = new File(arg.substring("--base-directory=".length()));
             } else if (arg.equals("--non-explore")) {
                 exploreProjects = false;
+            } else if (arg.equals("--build")) {
+                build = true;
             }
+
             i = inc(i, args);
         }
 
@@ -961,8 +966,12 @@ public class DependenciesSolver {
 
         solver.solveDependencies();
 
-        solver.pomTransformer.getListOfPOMs().save();
-        solver.pomTransformer.getRulesFiles().save(outputDirectory);
+        // Don't overwrite the poms or rules files during a build
+        if (!build) {
+            solver.pomTransformer.getListOfPOMs().save();
+            solver.pomTransformer.getRulesFiles().save(outputDirectory);
+        }
+        // Do generate the substvars though
         solver.saveSubstvars();
 
         if (!solver.issues.isEmpty()) {
