@@ -24,21 +24,16 @@ import java.util.Set;
 import java.util.TreeSet;
 
 public class LicensesScanner {
+
     public Set<String> discoverLicenses(List<License> projectLicenses) {
         Set<String> licenses = new TreeSet<String>();
         for (License license : projectLicenses) {
-            String licenseName = "";
-            if (license.getName() != null) {
-                licenseName = license.getName() + " ";
-            }
-            String licenseUrl = "";
-            if (license.getUrl() != null) {
-                licenseUrl = license.getUrl();
-            }
-            boolean recognized = recognizeLicense(licenses, licenseName, licenseUrl);
-            if (!recognized) {
+            String licenseName = license.getName() != null ? license.getName() + " " : "";
+            String licenseUrl  = license.getUrl() != null ? license.getUrl() : "";
+
+            if (!recognizeLicense(licenses, licenseName, licenseUrl)) {
                 String s = new SimpleQuestion("License " + licenseName + licenseUrl + " was not recognized, " +
-                                        "please enter a license name preferably in one of:" + getAvailableLicenses()).ask();
+                                        "please enter a license name preferably in one of: " + getAvailableLicenses()).ask();
                 if (s.length() > 0) {
                     licenses.add(s);
                 }
@@ -48,11 +43,9 @@ public class LicensesScanner {
         System.out.println();
         System.out.println("Checking licenses in the upstream sources...");
         LicenseCheckResult licenseResult = new LicenseCheckResult();
-        IOUtil.executeProcess(new String[]{"/bin/sh", "-c", "licensecheck `find . -type f`"},
-                licenseResult);
+        IOUtil.executeProcess(new String[]{"/bin/sh", "-c", "licensecheck `find . -type f`"}, licenseResult);
         for (String license : licenseResult.getLicenses()) {
-            boolean recognized = recognizeLicense(licenses, license, "");
-            if (!recognized) {
+            if (!recognizeLicense(licenses, license, "")) {
                 String s = new SimpleQuestion("License " + license + " was not recognized, " +
                                         "please enter a license name preferably in one of:" + getAvailableLicenses()).ask();
                 if (s.length() > 0) {
@@ -71,9 +64,10 @@ public class LicensesScanner {
     }
 
     private String getAvailableLicenses() {
-        return "Apache-2.0 Artistic BSD FreeBSD ISC CC-BY CC-BY-SA CC-BY-ND CC-BY-NC CC-BY-NC-SA\n"
-         + "CC-BY-NC-ND CC0 CDDL CPL Eiffel EPL-1.0 Expat GPL-2 GPL-3 LGPL-2 LGPL-2.1 LGPL-3"
-         + "GFDL-1.2 GFDL-1.3 GFDL-NIV LPPL MPL Perl PSF QPL W3C-Software ZLIB Zope";
+        return "Apache-2.0 Artistic BSD-2-clause BSD-3-clause BSD-4-clause ISC CC-BY CC-BY-SA\n"
+             + "CC-BY-ND CC-BY-NC CC-BY-NC-SA CC-BY-NC-ND CC0 CDDL CDDL-1.1 CPL Eiffel EPL-1.0 Expat\n"
+             + "GPL-2 GPL-3 LGPL-2 LGPL-2.1 LGPL-3 GFDL-1.2 GFDL-1.3 GFDL-NIV LPPL MPL-1.1\n"
+             + "MPL-2.0 Perl PSF QPL W3C-Software ZLIB Zope";
     }
 
     boolean recognizeLicense(Set<String> licenses, String licenseName, String licenseUrl) {
@@ -83,6 +77,15 @@ public class LicensesScanner {
         if (licenseName.contains("mit ") || licenseUrl.contains("mit-license")) {
             licenses.add("MIT");
             recognized = true;
+        } else if (licenseName.matches(".*bsd \\(?2[ -]clause\\)?.*") || licenseUrl.contains("bsd-2-clause")) {
+            licenses.add("BSD-2-clause");
+            recognized = true;
+        } else if (licenseName.matches(".*bsd \\(?3[ -]clause\\)?.*") || licenseUrl.contains("bsd-3-clause")) {
+            licenses.add("BSD-3-clause");
+            recognized = true;
+        } else if (licenseName.matches(".*bsd \\(?4[ -]clause\\)?.*") || licenseUrl.contains("bsd-4-clause")) {
+            licenses.add("BSD-4-clause");
+            recognized = true;
         } else if (licenseName.contains("bsd ") || licenseUrl.contains("bsd-license")) {
             licenses.add("BSD");
             recognized = true;
@@ -124,10 +127,28 @@ public class LicensesScanner {
                 licenses.add("GPL-3");
                 recognized = true;
             }
-
+        } else if (licenseName.contains("mpl") || licenseUrl.contains("mpl")) {
+            if (licenseName.contains("1.1") || licenseUrl.contains("1.1")) {
+                licenses.add("MPL-1.1");
+                recognized = true;
+            } else if (licenseName.contains("2.0") || licenseUrl.contains("2.0")) {
+                licenses.add("MPL-2.0");
+                recognized = true;
+            }
+        } else if (licenseName.contains("cddl") || licenseUrl.contains("cddl")) {
+            if (licenseName.contains("1.1") || licenseUrl.contains("1.1")) {
+                licenses.add("CDDL-1.1");
+                recognized = true;
+            } else if (licenseName.contains("1.0") || licenseUrl.contains("1.0")) {
+                licenses.add("CDDL");
+                recognized = true;
+            }
         } else if (licenseUrl.contains("http://creativecommons.org/licenses/by-sa/3.0")) {
             licenses.add("CC-BY-SA-3.0");
             recognized = true;
+        } else if (licenseName.contains("generated file")) {
+            // ignore the files reported as generated by licensecheck
+            recognized = true;
         }
         return recognized;
     }
